@@ -11,6 +11,7 @@ use Carp;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/
 	access_version_number
+	color_type_channels
 	color_type_name
 	copy_row_pointers
 	create_read_struct
@@ -38,6 +39,7 @@ our @EXPORT_OK = qw/
 	get_pCAL
 	get_pHYs
 	get_palette_max
+	get_rgb_to_gray_status
 	get_row_pointers
 	get_rowbytes
 	get_rows
@@ -102,8 +104,8 @@ our @EXPORT_OK = qw/
 	set_packing
 	set_packswap
 	set_palette_to_rgb
+	set_quantize
 	set_rgb_to_gray
-	set_rgb_to_gray_fixed
 	set_row_pointers
 	set_rows
 	set_sBIT
@@ -137,7 +139,6 @@ our @EXPORT_OK = qw/
 	write_info
 	write_png
 	write_to_scalar
-	color_type_name
 	copy_png
 	create_reader
 	create_writer
@@ -154,7 +155,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.52_07';
+our $VERSION = '0.52_08';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
